==> certmanager-model-v1-5.10.1-sources.jar: io/fabric8/certmanager/api/model/v1/IssuerBuilder.java <==
package io.fabric8.certmanager.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class IssuerBuilder extends io.fabric8.certmanager.api.model.v1.IssuerFluentImpl<io.fabric8.certmanager.api.model.v1.IssuerBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.certmanager.api.model.v1.Issuer,io.fabric8.certmanager.api.model.v1.IssuerBuilder>{
  public IssuerBuilder() {
    this(false);
  }
  public IssuerBuilder(java.lang.Boolean validationEnabled) {
    this(new Issuer(), validationEnabled);
  }
  public IssuerBuilder(io.fabric8.certmanager.api.model.v1.IssuerFluent<?> fluent) {
    this(fluent, false);
  }
  public IssuerBuilder(io.fabric8.certmanager.api.model.v1.IssuerFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Issuer(), validationEnabled);
  }
  public IssuerBuilder(io.fabric8.certmanager.api.model.v1.IssuerFluent<?> fluent,io.fabric8.certmanager.api.model.v1.Issuer instance) {
    this(fluent, instance, false);
  }
  public IssuerBuilder(io.fabric8.certmanager.api.model.v1.IssuerFluent<?> fluent,io.fabric8.certmanager.api.model.v1.Issuer instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public IssuerBuilder(io.fabric8.certmanager.api.model.v1.Issuer instance) {
    this(instance,false);
  }
  public IssuerBuilder(io.fabric8.certmanager.api.model.v1.Issuer instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.certmanager.api.model.v1.IssuerFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.certmanager.api.model.v1.Issuer build() {
    Issuer buildable = new Issuer(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IssuerBuilder that = (IssuerBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> certmanager-model-v1-6.2.0-sources.jar: io/fabric8/certmanager/api/model/v1/IssuerBuilder.java <==
package io.fabric8.certmanager.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IssuerBuilder extends IssuerFluentImpl<IssuerBuilder> implements VisitableBuilder<Issuer,IssuerBuilder>{
  public IssuerBuilder() {
    this(false);
  }
  public IssuerBuilder(Boolean validationEnabled) {
    this(new Issuer(), validationEnabled);
  }
  public IssuerBuilder(IssuerFluent<?> fluent) {
    this(fluent, false);
  }
  public IssuerBuilder(IssuerFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Issuer(), validationEnabled);
  }
  public IssuerBuilder(IssuerFluent<?> fluent,Issuer instance) {
    this(fluent, instance, false);
  }
  public IssuerBuilder(IssuerFluent<?> fluent,Issuer instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public IssuerBuilder(Issuer instance) {
    this(instance,false);
  }
  public IssuerBuilder(Issuer instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  IssuerFluent<?> fluent;
  Boolean validationEnabled;
  public Issuer build() {
    Issuer buildable = new Issuer(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  
}
